/*
 *  attacks.h - functions detecting attacks (header file)
 *
 *  Copyright (C) 1999 Hugo Haas
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef ATTACKS_H
#define ATTACKS_H

#include <time.h>

#include "defines.h"

/* General record structure */

struct port_scan_structure {
  __u16 first;
  __u16 last;
};

union attack_desc {
  unsigned long count; /* Number of packets received */
  struct port_scan_structure port_scan;
};

struct packet_record {
  __u32 ip;        /* IP address of the attacker */
  short triggered; /* TRUE if an attack has been detected, FALSE otherwise */
  time_t started;  /* First packet received */
  time_t latest;   /* Latest packet received */
  union attack_desc desc; /* Attack description */
  struct packet_record *prev, *next;
};

/* Functions recording an event and returning 0 if we should not
   log the packet with their corresponding structures */

/* Ping flood */
int record_ping(__u32 ipaddr);

/* UDP & TCP port scans */
int record_tcp_open(__u32 ipaddr, __u16 port);
int record_udp_open(__u32 ipaddr, __u16 port);

/* Smurf attacks */
int record_echoreply(__u32 ipaddr);

/* Initialisation, clean-up, etc */
void init_attack_records(void);

#endif
